@@ -2,13 +2,12 @@
 import os
 from django.db import IntegrityError
 
-from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase
+from pagador.configuracao.cadastro import CampoFormulario, FormularioBase, TipoDeCampo, CadastroBase, SelecaoBase, caminho_para_template
 from pagador.configuracao.cliente import Script, TipoScript
 
 
 def caminho_do_arquivo_de_template(arquivo):
-    diretorio = os.path.dirname(os.path.realpath(__file__))
-    return os.path.join(diretorio, "templates", arquivo)
+    return caminho_para_template(arquivo, meio_pagamento='deposito')
 
 
 class MeioPagamentoCadastro(CadastroBase):
